@@ -7,7 +7,7 @@ from ssl import SSLContext, PROTOCOL_TLSv1_2, CERT_REQUIRED
 from .config import AMAZON_CA, _CLUSTER_USER, _CLUSTER_PASS 
 
 try:
-    from cassandra_sig4.auth import SigV4AuthProvider   
+    from cassandra_sigv4.auth import SigV4AuthProvider   
     _auth_provider = SigV4AuthProvider()
 except:
     from cassandra.auth import PlainTextAuthProvider
