@@ -2,12 +2,15 @@
 """
     AWS KEYSPACE CONNECTOR UTIL
 """
+import logging
 import os
 
+import cassandra
 from cassandra.cqlengine import management
 
 from .connection import connect
 
+
 __all__ = ["migrate", "run_migrate", "create_ksp", "proxydb"]
 
 _models_to_migrate = set()
@@ -32,7 +35,14 @@ def run_migrate():
     """
     os.environ["CQLENG_ALLOW_SCHEMA_MANAGEMENT"] = "1"
     for model in _models_to_migrate:
-        management.sync_table(model, keyspaces=[os.getenv("CLUSTER_KSP")])
+        try:
+            management.sync_table(model, keyspaces=[os.getenv("CLUSTER_KSP")])
+            logging.info(f"{model.__table_name__} table successfully synchronized.")
+        except KeyError as e:
+            logging.warning(f"table creation {e} has started, please wait a minute.")
+        except cassandra.InvalidRequest as e:
+            logging.warning(e)
+            logging.warning("the {model.__table_name__} is not ready yet, please wait a minute.")
 
 
 @connect
@@ -42,6 +52,7 @@ def create_ksp(keyspace=None):
 
     os.environ["CQLENG_ALLOW_SCHEMA_MANAGEMENT"] = "1"
     management.create_keyspace_simple(ksp, 1)
+    logging.info(f"the keyspace {ksp} was created.")
 
 
 @connect
